@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-    flaskext.admin
+    flask.ext.admin
     ~~~~~~~~~~~~~~
 
-    Description of the module goes here...
+    Flask-Admin is a Flask extension module that aims to be a
+    flexible, customizable web-based interface to your datastore.
 
     :copyright: (c) 2011 by wilsaj.
     :license: BSD, see LICENSE for more details.
@@ -18,16 +19,12 @@ import time
 import types
 
 import flask
-from flask import (current_app, flash, g, Module, render_template,
-                   redirect, request, session, url_for)
+from flask import flash, render_template, redirect, request, url_for
 from flaskext.sqlalchemy import Pagination
-import jinja2.exceptions
 import sqlalchemy as sa
-import sqlalchemy.ext.declarative
 from sqlalchemy.orm.exc import NoResultFound
 from wtforms import widgets, validators
 from wtforms import fields as wtf_fields
-from wtforms.form import Form
 from wtforms.ext.sqlalchemy.orm import model_form, converts, ModelConverter
 from wtforms.ext.sqlalchemy import fields as sa_fields
 
@@ -555,6 +552,6 @@ class AdminConverter(ModelConverter):
         return wtf_fields.DateTimeField(**field_args)
 
     @converts('Time')
-    def conv_Date(self, field_args, **extra):
+    def conv_Time(self, field_args, **extra):
         field_args['widget'] = TimePickerWidget()
         return TimeField(**field_args)
